@@ -151,7 +151,10 @@ def set_code(reader, request, code_type="tenant_code"):
         # # tornado6.0.4 is ok
         # code = request.get_cookie(reader_key, "")
         # tornado5.1.1 is ok
-        code = request.cookies.get(reader_key, "")
+        # code: Set-Cookie: env_c=gog <Morsel: env_c=gog>
+        # request.cookies is A dictionary of Cookie.Morsel objects
+        # tornado5.1.1 source code->tornado-httputil.py-HTTPServerRequest-cookies
+        code = request.cookies.get(reader_key, "").value
     elif reader_type == ReaderType.RequestHeader:
         code = request.headers[reader_key] if reader_key in request.headers else ""
     elif reader_type == ReaderType.QueryString:
@@ -169,11 +172,11 @@ def set_code(reader, request, code_type="tenant_code"):
         code = ""
 
     # 设置用户自定义字段值
-    if type == "tenant_code" and not config.custom_tenant_code:
+    if code_type == "tenant_code" and not config.custom_tenant_code:
         config.custom_tenant_code = code
-    elif type == "user_code" and not config.custom_user_code:
+    elif code_type == "user_code" and not config.custom_user_code:
         config.custom_user_code = code
-    elif type == "env_code" and not config.custom_env_code:
+    elif code_type == "env_code" and not config.custom_env_code:
         config.custom_env_code = code
 
     return code
